#!/bin/bash

NOTEBOOK_DIR=$HOME/notebooks
USER_ID=$(id -u)
THE_USER=$USER

mkdir -p $NOTEBOOK_DIR

cat << EOF > kernel.json
{
 "argv": [
  "python",
  "-m",
  "ipykernel_launcher",
  "-f",
  "{connection_file}"
 ],
 "display_name": "Python 3",
 "language": "python",
 "env": {
     "LD_LIBRARY_PATH":"/Jpp/externals/dbclient//lib/:/Jpp/externals/antares-dataformat/:/Jpp/externals/aanet//evt:/Jpp/externals/aanet/:/Jpp/out//Linux/lib/:/opt/root/lib",
     "PYTHONPATH":"/Jpp/externals/aanet/:/opt/root/lib",
     "ROOTSYS":"/opt/root",
     "AADIR": "/Jpp/externals/aanet/"
 }
}
EOF

cat << EOF > $NOTEBOOK_DIR/.bashrc
cd /opt/root && source bin/thisroot.sh
cd /Jpp && source setenv.sh
cd $NOTEBOOK_DIR
EOF

cat << EOF > Dockerfile
FROM docker.km3net.de/km3book:1.0.0
RUN useradd -d $NOTEBOOK_DIR -u $(id -u) -s /bin/bash $USER
RUN apt-get install -qq -y vim
RUN rm -f /usr/local/share/jupyter/kernels/python3/kernel.json
ADD kernel.json /usr/local/share/jupyter/kernels/python3/kernel.json
RUN chown $USER /usr/local/share/jupyter/kernels/python3/kernel.json

USER $USER
CMD jupyter lab --ip=0.0.0.0 --port=8888 --no-browser --notebook-dir=$NOTEBOOK_DIR
#CMD bash
EXPOSE 22
EOF

sudo docker build -t mykm3book -f Dockerfile .
chown -R $THE_USER $NOTEBOOK_DIR

cat << EOF > run.sh
#!/bin/bash
sudo docker run -p 8888:8888 -p 2200:22 -u $USER_ID -v $NOTEBOOK_DIR:$NOTEBOOK_DIR -it mykm3book
EOF

echo
echo
echo The run script has been generated. From now on, please execute
echo
echo "    ./run.sh"
echo
echo "to launch the JupyterLab instance. I'll do it for you in 5 seconds!"
echo
echo

sleep 5

chmod +x run.sh
./run.sh